Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(837)

Unified Diff: chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java

Issue 189133005: Rename chromium_testshell target to chrome_shell_apk. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java
diff --git a/chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java b/chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java
index 2630d9758d0563b0e2578c9ce8eea74e62b0b423..44f02a39c68203bdc0c5ee28cb1d7384f04a0b43 100644
--- a/chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java
+++ b/chrome/android/shell/javatests/src/org/chromium/chrome/shell/ChromeShellTestBase.java
@@ -40,7 +40,7 @@ public class ChromeShellTestBase extends ActivityInstrumentationTestCase2<Chrome
ThreadUtils.runOnUiThreadBlocking(new Runnable() {
@Override
public void run() {
- CommandLine.initFromFile("/data/local/tmp/chromium-testshell-command-line");
+ CommandLine.initFromFile("/data/local/tmp/chrome-shell-command-line");
try {
BrowserStartupController.get(targetContext).startBrowserProcessesSync(
BrowserStartupController.MAX_RENDERERS_LIMIT);
@@ -93,7 +93,7 @@ public class ChromeShellTestBase extends ActivityInstrumentationTestCase2<Chrome
runTestOnUiThread(new Runnable() {
@Override
public void run() {
- TestShellTab tab = activity.getActiveTab();
+ ChromeShellTab tab = activity.getActiveTab();
if (tab != null) {
isLoaded.set(!tab.isLoading()
&& !TextUtils.isEmpty(tab.getContentView().getUrl()));
@@ -112,7 +112,7 @@ public class ChromeShellTestBase extends ActivityInstrumentationTestCase2<Chrome
}
/**
* Clear all files and folders in the Chromium testshell's application directory except 'lib'.
*
* The 'cache' directory is recreated as an empty directory.
*
@@ -112,7 +112,7 @@ public class ChromeShellTestBase extends ActivityInstrumentationTestCase2<Chrome
}
/**
- * Clear all files and folders in the Chromium testshell's application directory except 'lib'.
+ * Clear all files and folders in the ChromeShell's application directory except 'lib'.
*
* The 'cache' directory is recreated as an empty directory.

Powered by Google App Engine
This is Rietveld 408576698